@@ -35,7 +35,7 @@ c            to be safe, parameters are written in a file first and read
 c            again ; this will avoid the possible difference of internal
 c            parameter values read from original param and SkeletonParam
 c
-         call copenfw(TempDev, SkeletonFile, icon)
+         call copenNLfw(TempDev, SkeletonFile, icon)
          if(icon .ne. 0) then
             call cerrorMsg(SkeletonFile, 1)
             call cerrorMsg('File shown above cannot be opened',0)
@@ -49,7 +49,7 @@ c           at flesh time, you don't need to rewrite Job
          endif
          call cwriteParam(TempDev, 1)
          close(TempDev)
-         call copenf(TempDev, SkeletonFile, icon)
+         call copenNLf(TempDev, SkeletonFile, icon)
          call creadParam(TempDev)
          close(TempDev)
 c            restore Job
@@ -61,6 +61,8 @@ c        reset parameters.
          BorderHeightH = HeightOfInj + 1.0d0    ! from v6.10
       endif
 
+      EventsInTheRun = 0      ! moved from ciniTracking0. 2001.09/30
+
       if(DestEventNo(2) .eq. 0) then
          DestEventNo(2) = DestEventNo(1)
       elseif(DestEventNo(1) .lt. 0) then
@@ -143,20 +145,9 @@ c         user hook
 #include  "Zheavyv.h"
 
 c
+
       integer i, now(2)
-#if defined Solaris
-      integer time
-#endif
-
 c  
-c      ********** 
-c      next  is a "directive" for absoft f90.
-c      which is to make the call TIME as if call time.
-c      For absoft f90 ; we have to treat all variable in upper case
-c      but there is no TIME tourine in the system.
-c
-cdir$ NAME (TIME="time")
-
 c
 c
       ObserveAS = index(Generate, 'as')  .gt. 0 .or.
@@ -167,7 +158,7 @@ c
          SkipPtclGen = 0
       endif
 
-      EventsInTheRun = 0
+
 
       RefreshIR = InitRN(1) .lt. 0 .and. 
      *        ( Job .ne. 'flesh' .and. Job .ne. 'newflesh')
@@ -176,12 +167,7 @@ c
          call rnd1r(InitRN)     ! init randeom number generator
 c      *****************
       elseif(.not. RefreshIR .and. InitRN(2) .lt. 0) then
-#if defined Solaris
-         now(1)= time()
-#else
-         call time(now(1))
-#endif
-         now(2) =-InitRN(2)
+         call cmkSeed(0, now)   ! make seed using timer and hostname
          call rnd1r(now)
 c     ******************
       endif
@@ -270,7 +256,7 @@ c             skeleton file if distjob is employed.
                else
                   Job = 'flesh'
                endif
-               call copenfw(TempDev, SkeletonFile, icon)
+               call copenNLfw(TempDev, SkeletonFile, icon)
                if(icon .ne. 0) then
                   call cerrorMsg(SkeletonFile, 1)
                   call cerrorMsg(
@@ -368,7 +354,7 @@ c        **************************************** read cont job info
 #include "Zmanagerp.h"
       integer icon
 
-      call copenf(TempDev, ContFile,icon)
+      call copenNLf(TempDev, ContFile,icon)
       if(icon .ne. 0) then
          call cerrorMsg(ContFile, 1)
          call cerrorMsg('File shown above seems missing',0)
@@ -380,7 +366,7 @@ c        **************************************** read cont job info
       implicit none
 #include "Zmanagerp.h"
       integer icon
-      call copenf(TempDev, SkeletonFile, icon)
+      call copenNLf(TempDev, SkeletonFile, icon)
       if(icon .ne. 0 ) then
          call cerrorMsg(SkeletonFile, 1)
          call cerrorMsg('File shown above seems missing',0)
